@@ -34,6 +34,7 @@
 #include "hard-locale.h"
 #include "human.h"
 #include "physmem.h"
+#include "posixver.h"
 #include "stdio-safer.h"
 #include "xmemcoll.h"
 #include "xstrtol.h"
@@ -51,7 +52,7 @@ struct rlimit { size_t rlim_cur; };
 
 #define AUTHORS N_ ("Mike Haertel and Paul Eggert")
 
-#if defined ENABLE_NLS && HAVE_LANGINFO_H
+#if HAVE_LANGINFO_H
 # include <langinfo.h>
 #endif
 
@@ -90,7 +91,7 @@ double strtod ();
 #define NEGATION_SIGN   '-'
 #define NUMERIC_ZERO    '0'
 
-#ifdef ENABLE_NLS
+#if HAVE_SETLOCALE
 
 static char decimal_point;
 static int th_sep; /* if CHAR_MAX + 1, then there is no thousands separator */
@@ -193,15 +194,9 @@ static char fold_toupper[UCHAR_LIM];
 
 #define MONTHS_PER_YEAR 12
 
-#if defined ENABLE_NLS && HAVE_NL_LANGINFO
-# define MONTHTAB_CONST /* empty */
-#else
-# define MONTHTAB_CONST const
-#endif
-
 /* Table mapping month names to integers.
    Alphabetic order allows binary search. */
-static MONTHTAB_CONST struct month monthtab[] =
+static struct month monthtab[] =
 {
   {"APR", 4},
   {"AUG", 8},
@@ -326,11 +321,6 @@ Other options:\n\
 "), DEFAULT_TMPDIR);
       fputs (_("\
   -z, --zero-terminated     end lines with 0 byte, not newline\n\
-"), stdout);
-      if (POSIX2_VERSION < 200112)
-	fputs (_("\
-  +POS1 [-POS2]             start a key at POS1, end it before POS2 (origin 0)\n\
-                              Warning: this option is obsolete\n\
 "), stdout);
       fputs (HELP_OPTION_DESCRIPTION, stdout);
       fputs (VERSION_OPTION_DESCRIPTION, stdout);
@@ -353,7 +343,7 @@ The locale specified by the environment affects sort order.\n\
 Set LC_ALL=C to get the traditional sort order that uses\n\
 native byte values.\n\
 "), stdout );
-      puts (_("\nReport bugs to <bug-textutils@gnu.org>."));
+      printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
     }
   /* Don't use EXIT_FAILURE here in case it is defined to be 1.
      POSIX requires that sort return 1 IFF invoked with -c and
@@ -362,6 +352,8 @@ native byte values.\n\
   exit (status);
 }
 
+#define COMMON_SHORT_OPTIONS "-bcdfgik:mMno:rsS:t:T:uz"
+
 static struct option const long_options[] =
 {
   {"ignore-leading-blanks", no_argument, NULL, 'b'},
@@ -538,7 +530,7 @@ zaptemp (const char *name)
       }
 }
 
-#if defined ENABLE_NLS && HAVE_NL_LANGINFO
+#if HAVE_NL_LANGINFO
 
 static int
 struct_month_cmp (const void *m1, const void *m2)
@@ -570,7 +562,7 @@ inittables (void)
 	fold_toupper[i] = i;
     }
 
-#if defined ENABLE_NLS && HAVE_NL_LANGINFO
+#if HAVE_NL_LANGINFO
   /* If we're not in the "C" locale, read different names for months.  */
   if (hard_LC_TIME)
     {
@@ -593,7 +585,7 @@ inittables (void)
       qsort ((void *) monthtab, MONTHS_PER_YEAR,
 	     sizeof (struct month), struct_month_cmp);
     }
-#endif /* NLS */
+#endif
 }
 
 /* Specify the amount of main memory to use when sorting.  */
@@ -1368,10 +1360,9 @@ keycompare (const struct line *a, const struct line *b)
 	}
       else if (key->month)
 	diff = getmonth (texta, lena) - getmonth (textb, lenb);
-#ifdef ENABLE_NLS
       /* Sorting like this may become slow, so in a simple locale the user
          can select a faster sort that is similar to ascii sort  */
-      else if (hard_LC_COLLATE)
+      else if (HAVE_SETLOCALE && hard_LC_COLLATE)
 	{
 	  if (ignore || translate)
 	    {
@@ -1409,7 +1400,6 @@ keycompare (const struct line *a, const struct line *b)
 	  else
 	    diff = xmemcoll (texta, lena, textb, lenb);
 	}
-#endif
       else if (ignore)
 	{
 #define CMP_WITH_IGNORE(A, B)						\
@@ -1529,10 +1519,8 @@ compare (register const struct line *a, register const struct line *b)
     diff = - NONZERO (blen);
   else if (blen == 0)
     diff = NONZERO (alen);
-#ifdef ENABLE_NLS
-  else if (hard_LC_COLLATE)
+  else if (HAVE_SETLOCALE && hard_LC_COLLATE)
     diff = xmemcoll (a->text, alen, b->text, blen);
-#endif
   else if (! (diff = memcmp (a->text, b->text, min (alen, blen))))
     diff = alen < blen ? -1 : alen != blen;
 
@@ -2169,6 +2157,10 @@ main (int argc, char **argv)
   int c = 0;
   int checkonly = 0, mergeonly = 0, nfiles = 0;
   int posix_pedantic = (getenv ("POSIXLY_CORRECT") != NULL);
+  bool obsolete_usage = (posix2_version () < 200112);
+  char const *short_options = (obsolete_usage
+			       ? COMMON_SHORT_OPTIONS "y::"
+			       : COMMON_SHORT_OPTIONS "y:");
   char *minus = "-", **files;
   char const *outfile = minus;
   static int const sigs[] = { SIGHUP, SIGINT, SIGPIPE, SIGTERM };
@@ -2185,13 +2177,12 @@ main (int argc, char **argv)
 
   atexit (cleanup);
 
-#ifdef ENABLE_NLS
-
   hard_LC_COLLATE = hard_locale (LC_COLLATE);
-# if HAVE_NL_LANGINFO
+#if HAVE_NL_LANGINFO
   hard_LC_TIME = hard_locale (LC_TIME);
-# endif
+#endif
 
+#if HAVE_SETLOCALE
   /* Let's get locale's representation of the decimal point */
   {
     struct lconv *lconvp = localeconv ();
@@ -2208,8 +2199,7 @@ main (int argc, char **argv)
     if (! th_sep || lconvp->thousands_sep[1])
       th_sep = CHAR_MAX + 1;
   }
-
-#endif /* NLS */
+#endif
 
   have_read_stdin = 0;
   inittables ();
@@ -2257,13 +2247,12 @@ main (int argc, char **argv)
 
       if (c == -1
 	  || (posix_pedantic && nfiles != 0
-	      && ! (POSIX2_VERSION < 200112
+	      && ! (obsolete_usage
 		    && ! checkonly
 		    && optind != argc
 		    && argv[optind][0] == '-' && argv[optind][1] == 'o'
 		    && (argv[optind][2] || optind + 1 != argc)))
-	  || ((c = getopt_long (argc, argv,
-				"-bcdfgik:mMno:rsS:t:T:uy::z",
+	  || ((c = getopt_long (argc, argv, short_options,
 				long_options, NULL))
 	      == -1))
 	{
@@ -2275,7 +2264,7 @@ main (int argc, char **argv)
 	{
 	case 1:
 	  key = NULL;
-	  if (POSIX2_VERSION < 200112 && optarg[0] == '+')
+	  if (obsolete_usage && optarg[0] == '+')
 	    {
 	      /* Treat +POS1 [-POS2] as a key if possible; but silently
 		 treat an operand as a file if it is not a valid +POS1.  */
@@ -2292,10 +2281,6 @@ main (int argc, char **argv)
 		}
 	      else
 		{
-		  if (! posix_pedantic)
-		    error (0, 0,
-			   _("warning: `sort %s' is obsolete; use `sort -k'"),
-			   optarg);
 		  if (optind != argc && argv[optind][0] == '-'
 		      && ISDIGIT (argv[optind][1]))
 		    {
